package App::lcpan::CmdBundle::metasyntactic;

our $DATE = '2017-02-06'; # DATE
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: More lcpan subcommands related to Acme::MetaSyntactic

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::CmdBundle::metasyntactic - More lcpan subcommands related to Acme::MetaSyntactic

=head1 VERSION

This document describes version 0.002 of App::lcpan::CmdBundle::metasyntactic (from Perl distribution App-lcpan-CmdBundle-metasyntactic), released on 2017-02-06.

=head1 SYNOPSIS

=head1 DESCRIPTION

This bundle provides the following lcpan subcommands:

=over

=item * L<lcpan metasyntactic-themes|App::lcpan::Cmd::metasyntactic_themes>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan-CmdBundle-metasyntactic>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lcpan-CmdBundle-metasyntactic>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan-CmdBundle-metasyntactic>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<lcpan>

L<Acme::MetaSyntactic>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
